"""General-use classes to interact with the MediaStore service through CloudFormation.

See Also:
    `AWS developer guide for MediaStore
    <https://docs.aws.amazon.com/mediastore/latest/ug/what-is.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import mediastore as _raw

# noinspection PyUnresolvedReferences
from .._raw.mediastore import *
